@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Nef_3/include/CGAL/Nef_3/SNC_structure.h $
-// $Id: SNC_structure.h 33d9560b20b 2023-01-19T00:39:36Z Giles Bathgate
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.3/Nef_3/include/CGAL/Nef_3/SNC_structure.h $
+// $Id: include/CGAL/Nef_3/SNC_structure.h cefe3007d59 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -34,7 +34,7 @@
 #include <CGAL/Nef_2/debug.h>
 #include <CGAL/Nef_2/Object_index.h>
 
-#include <boost/optional.hpp>
+#include <optional>
 #include <boost/none.hpp>
 
 namespace CGAL {
@@ -384,13 +384,13 @@ public:
   expensive operation.}*/
 
   SNC_structure() :
-    boundary_item_(boost::none), sm_boundary_item_(boost::none),
+    boundary_item_(std::nullopt), sm_boundary_item_(std::nullopt),
     vertices_(), halfedges_(), halffacets_(), volumes_(),
     shalfedges_(), shalfloops_(), sfaces_() {}
   ~SNC_structure() { CGAL_NEF_TRACEN("~SNC_structure: clearing "<<this); clear(); }
 
   SNC_structure(const Self& D) :
-    boundary_item_(boost::none), sm_boundary_item_(boost::none),
+    boundary_item_(std::nullopt), sm_boundary_item_(std::nullopt),
     vertices_(D.vertices_), halfedges_(D.halfedges_),
     halffacets_(D.halffacets_), volumes_(D.volumes_),
     shalfedges_(D.shalfedges_), shalfloops_(D.shalfloops_),
@@ -401,8 +401,8 @@ public:
     if ( this == &D )
       return *this;
     clear();
-    boundary_item_.clear(boost::none);
-    sm_boundary_item_.clear(boost::none);
+    boundary_item_.clear(std::nullopt);
+    sm_boundary_item_.clear(std::nullopt);
     vertices_ = D.vertices_;
     halfedges_ = D.halfedges_;
     halffacets_ = D.halffacets_;
@@ -419,17 +419,17 @@ public:
   }
 
   void clear_boundary() {
-    boundary_item_.clear(boost::none);
-    sm_boundary_item_.clear(boost::none);
+    boundary_item_.clear(std::nullopt);
+    sm_boundary_item_.clear(std::nullopt);
   }
 
   void clear_snc_boundary() {
-    boundary_item_.clear(boost::none);
+    boundary_item_.clear(std::nullopt);
   }
 
   void clear() {
-    boundary_item_.clear(boost::none);
-    sm_boundary_item_.clear(boost::none);
+    boundary_item_.clear(std::nullopt);
+    sm_boundary_item_.clear(std::nullopt);
     vertices_.destroy();
     halfedges_.destroy();
     halffacets_.destroy();
@@ -441,10 +441,10 @@ public:
 
   template <typename H>
   bool is_boundary_object(H h) const
-  { return boundary_item_[h]!=boost::none; }
+  { return boundary_item_[h]!=std::nullopt; }
   template <typename H>
   bool is_sm_boundary_object(H h) const
-  { return sm_boundary_item_[h]!=boost::none; }
+  { return sm_boundary_item_[h]!=std::nullopt; }
 
   template <typename H>
   Object_iterator& boundary_item(H h)
@@ -462,12 +462,12 @@ public:
 
   template <typename H>
   void undef_boundary_item(H h)
-  { CGAL_assertion(boundary_item_[h]!=boost::none);
-    boundary_item_[h] = boost::none; }
+  { CGAL_assertion(boundary_item_[h]!=std::nullopt);
+    boundary_item_[h] = std::nullopt; }
   template <typename H>
   void undef_sm_boundary_item(H h)
-  { CGAL_assertion(sm_boundary_item_[h]!=boost::none);
-    sm_boundary_item_[h] = boost::none; }
+  { CGAL_assertion(sm_boundary_item_[h]!=std::nullopt);
+    sm_boundary_item_[h] = std::nullopt; }
 
   void reset_iterator_hash(Object_iterator it)
   { SVertex_handle sv;
@@ -1035,7 +1035,7 @@ public:
 protected:
   void pointer_update(const Self& D);
 
-  typedef boost::optional<Object_iterator> Optional_object_iterator ;
+  typedef std::optional<Object_iterator> Optional_object_iterator ;
  private:
   Generic_handle_map<Optional_object_iterator> boundary_item_;
   Generic_handle_map<Optional_object_iterator> sm_boundary_item_;
