@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h $
-// $Id: snap.h 5cc58a4080c 2023-08-17T15:02:48+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.3/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h $
+// $Id: include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h cefe3007d59 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -27,11 +27,12 @@
 
 #include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
+#include <CGAL/boost/graph/Euler_operations.h>
 #include <CGAL/Polygon_mesh_processing/border.h>
 #include <CGAL/Polygon_mesh_processing/compute_normal.h>
 
 #include <CGAL/AABB_tree.h>
-#include <CGAL/AABB_traits.h>
+#include <CGAL/AABB_traits_3.h>
 #include <CGAL/AABB_halfedge_graph_segment_primitive.h>
 #include <CGAL/assertions.h>
 #include <CGAL/boost/graph/helpers.h>
@@ -104,9 +105,19 @@ void simplify_range(HalfedgeRange& halfedge_range,
   typedef CGAL::dynamic_halfedge_property_t<bool>                                 Halfedge_bool_tag;
   typedef typename boost::property_map<TriangleMesh, Halfedge_bool_tag>::type     Range_halfedges;
 
-  Range_halfedges range_halfedges = get(Halfedge_bool_tag(), tm);
-  for(halfedge_descriptor h : halfedge_range)
+#ifdef CGAL_PMP_SNAP_DEBUG_OUTPUT
+  static int i = 0;
+  std::ofstream out_in("results/before_simplification_" + std::to_string(i++) + ".polylines.txt");
+  out_in.precision(17);
+#endif
+
+  Range_halfedges range_halfedges = get(Halfedge_bool_tag(), tm, false);
+  for(halfedge_descriptor h : halfedge_range) {
+#ifdef CGAL_PMP_SNAP_DEBUG_OUTPUT
+    out_in << "2 " << get(vpm, source(h, tm)) << " " << get(vpm, target(h, tm)) << "\n";
+#endif
     put(range_halfedges, h, true);
+  }
 
   CGAL_postcondition_code(const std::size_t initial_n = halfedge_range.size();)
 
@@ -117,6 +128,9 @@ void simplify_range(HalfedgeRange& halfedge_range,
   while(!edges_to_test.empty())
   {
     const halfedge_descriptor h = *(edges_to_test.begin());
+    CGAL_precondition(is_border(h, tm));
+    CGAL_precondition(!is_border(opposite(h, tm), tm));
+
     edges_to_test.erase(edges_to_test.begin());
 
     const vertex_descriptor vs = source(h, tm);
@@ -132,8 +146,7 @@ void simplify_range(HalfedgeRange& halfedge_range,
 
     if(gt.compare_squared_distance_3_object()(ps,pt,CGAL::square(max_tol)) == SMALLER)
     {
-      const halfedge_descriptor prev_h = prev(h, tm);
-      const halfedge_descriptor next_h = next(h, tm);
+      CGAL_precondition_code(const halfedge_descriptor prev_h = prev(h, tm);)
       const halfedge_descriptor prev_oh = prev(opposite(h, tm), tm);
 
       // check that the border has at least 4 edges not to create degenerate volumes
@@ -186,19 +199,38 @@ void simplify_range(HalfedgeRange& halfedge_range,
         if(!CGAL::Euler::does_satisfy_link_condition(edge(h, tm), tm))
           continue;
 
+        // Since `o_h` is not a border halfedge, `prev(opp(h))` gets replaced with `opp(next(opp(h)))`.
+        // But `prev(opp(h))` might have been be a border edge whereas `opp(next(opp(h)))` might not be.
+        // So, if `opp(prev(opp(h)))` was a border halfedge in the range, we must add `next(opp(h))`
+        // to the range.
         const halfedge_descriptor opoh = opposite(prev(opposite(h, tm), tm), tm);
-        if(is_border(opoh, tm))
+        bool was_opoh_border_in_range = false;
+        const halfedge_descriptor noh = next(opposite(h, tm), tm);
+
+        if(is_border(opoh, tm) && get(range_halfedges, opoh)) {
+          was_opoh_border_in_range = true;
           edges_to_test.erase(opoh);
+        }
 
         vertex_descriptor v = Euler::collapse_edge(edge(h, tm), tm);
+        CGAL_postcondition(bool(is_border(v, tm)));
+        CGAL_postcondition(target(prev_h, tm) == v);
 
         put(vpm, v, new_p);
         put(tolerance_map, v, new_tolerance);
 
-        if(get(range_halfedges, prev_h))
-          edges_to_test.insert(prev_h);
-        if(next_h != opoh && get(range_halfedges, next_h))
-          edges_to_test.insert(next_h);
+        if(was_opoh_border_in_range)
+        {
+          CGAL_assertion(is_border(noh, tm));
+          put(range_halfedges, noh, true);
+        }
+
+        for(halfedge_descriptor ih : halfedges_around_target(v, tm))
+        {
+          if(get(range_halfedges, ih))
+            edges_to_test.insert(ih);
+        }
+
         ++collapsed_n;
       }
     }
@@ -227,7 +259,7 @@ template <typename TriangleMesh,
 class Projection_traits
 {
   typedef typename AABBTraits::FT                                          FT;
-  typedef typename AABBTraits::Point_3                                     Point;
+  typedef typename AABBTraits::Point                                       Point;
   typedef typename AABBTraits::Primitive                                   Primitive;
   typedef typename AABBTraits::Bounding_box                                Bounding_box;
   typedef typename AABBTraits::Primitive::Id                               Primitive_id;
@@ -373,7 +405,7 @@ public:
       return;
 
     const typename Primitive::Datum& s = primitive.datum(m_traits.shared_data());
-    if(m_traits.equal_3_object()(s[0], query) || m_traits.equal_3_object()(s[1], query))
+    if(m_traits.equal_object()(s[0], query) || m_traits.equal_object()(s[1], query))
     {
       // If we are NOT using the same mesh and the query is (geometrically) equal to one extremity
       // of the target edge, we don't want to move the source point away from the target point
@@ -689,12 +721,18 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
     halfedge_descriptor h_to_split = es.first;
     CGAL_assertion(is_border(h_to_split, tm_T));
 
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+      std::cout << " -.-.-. Splitting " << edge(h_to_split, tm_T) << " |||| "
+                << " Vs " << source(h_to_split, tm_T) << " (" << tm_T.point(source(h_to_split, tm_T)) << ")"
+                << " --- Vt " << target(h_to_split, tm_T) << " (" << tm_T.point(target(h_to_split, tm_T)) << ")" << std::endl;
+#endif
+
     Vertices_with_new_position& splitters = es.second;
 
     if(splitters.size() > 1)
     {
 #ifdef CGAL_PMP_SNAP_DEBUG_PP
-      std::cout << " _______ Multiple splitting points on the same halfedge" << std::endl;
+      std::cout << " _______ Multiple splitting points on the same halfedge, sorting..." << std::endl;
 #endif
 
       const Point_ref hsp = get(vpm_T, source(h_to_split, tm_T));
@@ -717,20 +755,36 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
       const vertex_descriptor splitter_v = target(splitter_h, tm_S);
       const Point new_position = is_source_mesh_fixed ? get(vpm_S, splitter_v) : vnp.second;
 
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+      std::cout << "With point: " << new_position << " (first choice: " << vnp.second << ")" << std::endl;
+#endif
+
       bool do_split = true;
 
       // In case of self-snapping, avoid degenerate caps
       const bool is_same_mesh = (&tm_T == &tm_S);
-      if(is_same_mesh && target(next(opposite(h_to_split, tm_T), tm_T), tm_T) == splitter_v)
+      if(is_same_mesh && target(next(opposite(h_to_split, tm_T), tm_T), tm_T) == splitter_v) {
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+        std::cout << "Reject split (A)" << std::endl;
+#endif
         do_split = false;
+      }
 
       // Do not split if it would create a degenerate needle
       if((new_position == get(vpm_T, target(h_to_split, tm_T))) ||
-         (new_position == get(vpm_T, source(h_to_split, tm_T))))
+         (new_position == get(vpm_T, source(h_to_split, tm_T)))) {
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+        std::cout << "Reject split (B)" << std::endl;
+#endif
         do_split = false;
+      }
 
-      if(!first_split && new_position == previous_split_position)
+      if(!first_split && new_position == previous_split_position) {
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+        std::cout << "Reject split (C)" << std::endl;
+#endif
         do_split = false;
+      }
 
       // check if the new faces after split will not be degenerate
       const Point& p0 = new_position;
@@ -755,13 +809,21 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
 
       if(first_split_face)
       {
-        if(p0p2 <= 0 || collinear(p0,p1,p2) || collinear(p0,p2,p3))
+        if(p0p2 <= 0 || collinear(p0,p1,p2) || collinear(p0,p2,p3)) {
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+        std::cout << "Reject split (D)" << std::endl;
+#endif
           do_split = false;
+        }
       }
       else
       {
-        if(p1p3 <= 0 || collinear(p0,p1,p3) || collinear(p1,p2,p3))
+        if(p1p3 <= 0 || collinear(p0,p1,p3) || collinear(p1,p2,p3)) {
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+        std::cout << "Reject split (E)" << std::endl;
+#endif
           do_split = false;
+        }
       }
 
       if(do_split && !is_source_mesh_fixed)
@@ -770,6 +832,9 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
         {
           if(!is_border(h,tm_S) && collinear(get(vpm_S, source(h,tm_S)), new_position, get(vpm_S, target(next(h,tm_S),tm_S))))
           {
+#ifdef CGAL_PMP_SNAP_DEBUG_PP
+        std::cout << "Reject split (F)" << std::endl;
+#endif
             do_split = false;
             break;
           }
@@ -780,10 +845,6 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
       }
 
 #ifdef CGAL_PMP_SNAP_DEBUG_PP
-      std::cout << " -.-.-. Splitting " << edge(h_to_split, tm_T) << " |||| "
-                << " Vs " << source(h_to_split, tm_T) << " (" << tm_T.point(source(h_to_split, tm_T)) << ")"
-                << " --- Vt " << target(h_to_split, tm_T) << " (" << tm_T.point(target(h_to_split, tm_T)) << ")" << std::endl;
-      std::cout << "With point: " << new_position << " (init: " << vnp.second << ")" << std::endl;
       std::cout << "Actually split? " << do_split << std::endl;
 #endif
 
@@ -875,7 +936,7 @@ std::size_t snap_non_conformal_one_way(const HalfedgeRange& halfedge_range_S,
   typedef typename boost::property_traits<VPMT>::value_type                       Point;
 
   typedef CGAL::AABB_halfedge_graph_segment_primitive<TriangleMesh, VPMT>         Primitive;
-  typedef CGAL::AABB_traits<GT, Primitive>                                        AABB_Traits;
+  typedef CGAL::AABB_traits_3<GT, Primitive>                                      AABB_Traits;
   typedef CGAL::AABB_tree<AABB_Traits>                                            AABB_tree;
 
   typedef std::pair<halfedge_descriptor, Point>                                   Vertex_with_new_position;
@@ -938,11 +999,11 @@ std::size_t snap_non_conformal_one_way(const HalfedgeRange& halfedge_range_S,
 
   for(halfedge_descriptor h : halfedge_range_T)
   {
-    CGAL_precondition(is_border(edge(h, tm_T), tm_T));
+    CGAL_precondition(is_border_edge(h, tm_T));
     if(get(locked_halfedges_T, h))
     {
 #ifdef CGAL_PMP_SNAP_DEBUG_PP
-      std::cout << edge(h, tm_T) << " is locked and not a valid target" << std::endl;
+      std::cout << edge(h, tm_T) << " [" << source(h, tm_T) << " - " << target(h, tm_T) << "] is locked and not a valid target" << std::endl;
 #endif
       continue;
     }
@@ -961,7 +1022,7 @@ std::size_t snap_non_conformal_one_way(const HalfedgeRange& halfedge_range_S,
 #endif
 
 #ifndef CGAL_LINKED_WITH_TBB
-  CGAL_static_assertion_msg (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
+  static_assert (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
                              "Parallel_tag is enabled but TBB is unavailable.");
 #else // CGAL_LINKED_WITH_TBB
   if(std::is_convertible<ConcurrencyTag, Parallel_tag>::value)
@@ -1233,10 +1294,10 @@ std::size_t snap_non_conformal(HalfedgeRange& halfedge_range_A,
   // We keep in memory pairs of source/target edges that are stitchable after vertex-vertex snapping
   // --> these halfedges should not be considered as targets in non-conformal snapping
   // Similarly, matching vertices whose incident edges have matching directions are also locked
-  Locked_vertices locked_vertices_A = get(Vertex_bool_tag(), tm_A);
-  Locked_vertices locked_vertices_B = get(Vertex_bool_tag(), tm_B);
-  Locked_halfedges locked_halfedges_A = get(Halfedge_bool_tag(), tm_A);
-  Locked_halfedges locked_halfedges_B = get(Halfedge_bool_tag(), tm_B);
+  Locked_vertices locked_vertices_A = get(Vertex_bool_tag(), tm_A, false);
+  Locked_vertices locked_vertices_B = get(Vertex_bool_tag(), tm_B, false);
+  Locked_halfedges locked_halfedges_A = get(Halfedge_bool_tag(), tm_A, false);
+  Locked_halfedges locked_halfedges_B = get(Halfedge_bool_tag(), tm_B, false);
 
   std::vector<std::pair<vertex_descriptor, vertex_descriptor> > locked_vertices;
   std::vector<halfedge_descriptor> locked_halfedges_A_vector, locked_halfedges_B_vector;
